@@ -22,10 +22,14 @@ def verifyApp(app):
                         'imagekit',
                         'upy',
                         'south',
+                        'upy.contrib.inspect',
+                        'modeltranslation',
+                        'upy.contrib.tabbed_translation',
                         'upy.contrib.cked',
                         'upy.contrib.colors',
                         'upy.contrib.language',
                         'upy.contrib.rosetta']
+
         
 def all_apps():
     """
